@@ -6,6 +6,8 @@ from mcp.types import TextContent
 
 from stac_mcp.tools.client import STACClient
 
+BBOX_MIN_COORDS = 4
+
 
 def handle_search_items(
     client: STACClient,
@@ -27,11 +29,19 @@ def handle_search_items(
         return {"type": "item_list", "count": len(items), "items": items}
     result_text = f"Found {len(items)} items:\n\n"
     for item in items:
-        result_text += f"**{item['id']}** (Collection: `{item['collection']}`)\n"
-        if item["datetime"]:
-            result_text += f"  Date: {item['datetime']}\n"
-        if item["bbox"]:
-            b = item["bbox"]
-            result_text += f"  BBox: [{b[0]:.2f}, {b[1]:.2f}, {b[2]:.2f}, {b[3]:.2f}]\n"
-        result_text += f"  Assets: {len(item['assets'])}\n\n"
+        item_id = item.get("id", "unknown")
+        collection_id = item.get("collection", "unknown")
+        result_text += f"**{item_id}** (Collection: `{collection_id}`)\n"
+        dt_value = item.get("datetime")
+        if dt_value:
+            result_text += f"  Date: {dt_value}\n"
+        bbox = item.get("bbox")
+        if isinstance(bbox, list | tuple) and len(bbox) >= BBOX_MIN_COORDS:
+            result_text += (
+                "  BBox: "
+                f"[{bbox[0]:.2f}, {bbox[1]:.2f}, {bbox[2]:.2f}, {bbox[3]:.2f}]\n"
+            )
+        assets = item.get("assets") or {}
+        asset_count = len(assets) if hasattr(assets, "__len__") else 0
+        result_text += f"  Assets: {asset_count}\n\n"
     return [TextContent(type="text", text=result_text)]
